@@ -50,6 +50,11 @@ NTL_OPEN_NNS
 #define NTL_WordVectorInputBlock 50
 #endif
 
+// controls release functionality
+
+#define NTL_RELEASE_THRESH (10000)
+// #define NTL_RELEASE_THRESH (0)
+
 
 class WordVector {  
 public:  
@@ -60,15 +65,18 @@ public:
 
 
   
-   WordVector() { rep = 0; }  
-   WordVector(INIT_SIZE_TYPE, long n) { rep = 0; DoSetLength(n); }  
-   WordVector(const WordVector& a) { rep = 0; *this = a; }     
+   WordVector() : rep(0) { }  
+   WordVector(INIT_SIZE_TYPE, long n) : rep(0) { DoSetLength(n); }  
+   WordVector(const WordVector& a) : rep(0) { *this = a; }     
 
    WordVector& operator=(const WordVector& a);  
 
    ~WordVector();  
    void kill(); 
 
+   void release() { if (MaxLength() > NTL_RELEASE_THRESH) kill(); }
+   // this conditinally kills the vector, if its size is excessive
+
    void DoSetLength(long n);
   
    void SetLength(long n)
